@@ -1,7 +1,7 @@
 from tkinter import *
 
 class GameScreen:
-    def __init__(self, master, color="black", title="TkGame - GameScreen", icon="TkGame\icon.ico"):
+    def __init__(self, master, color="black", title="TkGame - GameScreen", icon="TkGame\\images\\icon.ico"):
         self.master = master
         self.color = color
         self.frame = Frame(master)
